Learn R Programming

BCD (version 0.1.1)

MLEpoisBCD: Maximum Likelihood Estimation for a Bivariate Poisson Distribution via Conditional Specification

Description

Estimates the parameters of a bivariate Poisson distribution via Conditional Specification using maximum likelihood.

Usage

MLEpoisBCD(data, initial_values = NULL)

Value

A list of class "MLEpoisBCD" containing:

lambda1

estimated lambda1.

lambda2

estimated lambda2.

lambda3

estimated dependence parameter (must be in (0, 1]).

logLik

Maximum log-likelihood achieved.

AIC

Akaike Information Criterion.

BIC

Bayesian Information Criterion.

convergence

Convergence status from the optimizer (0 means successful).

Arguments

data

data frame or matrix with two columns, representing paired observations of count variables \((X, Y)\).

initial_values

optional named list with initial values for the parameters: lambda1, lambda2, and lambda3. If not provided, the function computes heuristic starting values.

Details

The model estimates parameters from a joint distribution for \((X, Y)\) with the form: $$ P(X = x, Y = y) = K(\lambda_1, \lambda_2, \lambda_3) \frac{\lambda_1^x \lambda_2^y \lambda_3^{xy}}{x! y!}, $$ where \( x, y = 0, 1, 2, \ldots \), and \( K(\lambda_1, \lambda_2, \lambda_3) \) is the normalizing constant.

See Also

dpoisBCD ppoisBCD rpoisBCD

Examples

Run this code
# Simulate data
data <- rpoisBCD(n = 50, lambda1 = 3, lambda2 = 5, lambda3 = 1)
result <- MLEpoisBCD(data)
print(result)

data(eplSeasonGoals)
MLEpoisBCD(eplSeasonGoals[["1819"]])

data(lensfaults)
MLEpoisBCD(lensfaults)

Run the code above in your browser using DataLab