Learn R Programming

BCD (version 0.1.1)

dpoisBCD: Joint Probability Mass Function for a Bivariate Poisson Distribution via Conditional Specification

Description

Computes the joint probability mass function (p.m.f.) of a Bivariate Poisson Conditionals distribution (BPCD) based on Ghosh, Marques, and Chakraborty (2021).

Usage

dpoisBCD(x, y, lambda1, lambda2, lambda3)

Value

probability \( P(X = x, Y = y) \) for each pair of \( x \) and \( y \).

Arguments

x

value of \( X \) that must be a non-negative integer

y

value of \( Y \) that must be a non-negative integer

lambda1

rate parameter for \( X \) that must be positive

lambda2

rate parameter for \( Y \) that must be positive

lambda3

dependence parameter that must be \((0, 1]\)

Details

The joint p.m.f. of the BGCD is $$ P(X = x, Y = y) = K(\lambda_1, \lambda_2, \lambda_3) \frac{\lambda_1^x \lambda_2^y \lambda_3^{xy}}{x! y!}, $$ where \( x, y = 0, 1, 2, \ldots \), and \( K(\lambda_1, \lambda_2, \lambda_3) \) is the normalizing constant computed by the function normalize_constant_BPCD.

Key properties of the BPCD include:

- Negative correlation for \( \lambda_3 < 1 \),

- Independence for \( \lambda_3 = 1 \).

References

Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. tools:::Rd_expr_doi("10.1080/02664763.2020.1793307")

See Also

rpoisBCD, ppoisBCD

Examples

Run this code
# Compute P(X = 1, Y = 2) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5
dpoisBCD(x = 1, y = 2, lambda1 = 0.5, lambda2 =  0.5, lambda3 =  0.5)

# Compute P(X = 0, Y = 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5
dpoisBCD(x = 0, y = 1, lambda1 = 0.5, lambda2 =  0.5, lambda3 =  0.5)

Run the code above in your browser using DataLab