Learn R Programming

BCD (version 0.1.1)

ppoisBCD: Cumulative Distribution Function for a Bivariate Poisson Distribution via Conditional Specification

Description

Computes the cumulative distribution function (c.d.f.) of a bivariate Poisson distribution (BPD) with conditional specification, as described by Ghosh, Marques, and Chakraborty (2021).

Usage

ppoisBCD(x, y, lambda1, lambda2, lambda3)

Value

The probability \( P(X \leq x, Y \leq y) \).

Arguments

x

value at which the c.d.f. is evaluated

y

value at which the c.d.f. is evaluated

lambda1

rate parameter for \( X \) that must be positive

lambda2

rate parameter for \( Y \) that must be positive

lambda3

dependence parameter that must be (0, 1]

References

Ghosh, I., Marques, F., & Chakraborty, S. (2021). A new bivariate Poisson distribution via conditional specification: properties and applications. Journal of Applied Statistics, 48(16), 3025-3047. tools:::Rd_expr_doi("10.1080/02664763.2020.1793307")

See Also

dpoisBCD rpoisBCD

Examples

Run this code
# Compute P(X \le 1, Y \le 1) with lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5
ppoisBCD(x = 1, y = 1, lambda1 = 0.5, lambda2 = 0.5, lambda3 = 0.5)

# Example with larger values
ppoisBCD(x = 2, y = 2, lambda1 = 1.0, lambda2 = 1.0, lambda3 = 0.8)

Run the code above in your browser using DataLab