Learn R Programming

BCD (version 0.1.1)

seedplant: Seed and Plant Count Data

Description

This dataset records the number of seeds sown and the number of resulting plants grown over plots of fixed area (5 square feet).

Usage

seedplant

Arguments

Format

A data frame with n rows and 2 variables:

X

Number of seeds sown.

Y

Number of plants grown.

#' @references Lakshminarayana, J., S. N. N. Pandit, and K. Srinivasa Rao. 1999. On a bivariate poisson distribution. Communications in Statistics - Theory and Methods, 28 (2), 267--276. tools:::Rd_expr_doi("10.1080/03610929908832297")

Ghosh, I., Marques, F., & Chakraborty, S. (2025). A form of bivariate binomial conditionals distributions. Communications in Statistics - Theory and Methods, 54(2), 534--553. tools:::Rd_expr_doi("10.1080/03610926.2024.2315294")

Examples

Run this code
data(seedplant)
head(seedplant)
plot(seedplant$X, seedplant$Y,
     xlab = "Seeds Sown",
     ylab = "Plants Grown",
     main = "Seed vs. Plant Count per Plot")

Run the code above in your browser using DataLab